==> 0.16.0.tar.gz: lib/src/services/viewport_scroller.dart <==
part of '../../ngx_core.dart';

/// Manages the scroll position.
class ViewportScroller {
  /// Creates a new viewport scroller.
  ViewportScroller(this._app);

  /// The application instance.
  final Application _app;

  /// The current scroll position.
  Point get scrollPosition => Point(dom.window.scrollX, dom.window.scrollY);

  /// Scrolls to the specified [anchor].
  void scrollToAnchor(String anchor,
      {Point offset = const Point(0, 0), bool smoothScroll = true}) {
    var element = dom.document.getElementById(anchor);
    element ??= dom.querySelector('[name="$anchor"]');
    if (element != null)
      scrollToElement(element, offset: offset, smoothScroll: smoothScroll);
  }

  /// Scrolls to the specified [element].
  void scrollToElement(dom.Element element,
      {Point offset = const Point(0, 0), bool smoothScroll = true}) {
    final rectangle = element.getBoundingClientRect();
    final left = rectangle.left + dom.window.pageXOffset;
    final top = rectangle.top + dom.window.pageYOffset;
    scrollToPosition(Point(left - offset.x, top - offset.y),
        smoothScroll: smoothScroll);
  }

  /// Scrolls to the specified [position].
  void scrollToPosition(Point position, {bool smoothScroll = true}) {
    if (!smoothScroll || !_app.supportsSmoothScroll)
      dom.window.scroll(position.x, position.y);
    else
      dom.window.scroll(
          {'behavior': 'smooth', 'left': position.x, 'top': position.y});
  }

  /// Scrolls to the top.
  void scrollToTop({bool smoothScroll = true}) =>
      scrollToPosition(const Point(0, 0), smoothScroll: smoothScroll);
}

==> 0.17.0.tar.gz: lib/src/services/viewport_scroller.dart <==
part of '../../ngx_core.dart';

/// Manages the scroll position.
class ViewportScroller {
  /// Creates a new viewport scroller.
  ViewportScroller(this._app);

  /// The application instance.
  final Application _app;

  /// The current scroll position.
  Point get scrollPosition => Point(dom.window.scrollX, dom.window.scrollY);

  /// Scrolls to the specified [anchor].
  void scrollToAnchor(String anchor,
      {Point offset = const Point(0, 0), bool smoothScroll = true}) {
    var element = dom.document.getElementById(anchor);
    element ??= dom.querySelector('[name="$anchor"]');
    if (element != null)
      scrollToElement(element, offset: offset, smoothScroll: smoothScroll);
  }

  /// Scrolls to the specified [element].
  void scrollToElement(dom.Element element,
      {Point offset = const Point(0, 0), bool smoothScroll = true}) {
    final rectangle = element.getBoundingClientRect();
    final left = rectangle.left + dom.window.pageXOffset;
    final top = rectangle.top + dom.window.pageYOffset;
    scrollToPosition(Point(left - offset.x, top - offset.y),
        smoothScroll: smoothScroll);
  }

  /// Scrolls to the specified [position].
  void scrollToPosition(Point position, {bool smoothScroll = true}) {
    if (!smoothScroll || !_app.supportsScrollBehavior)
      dom.window.scrollTo(position.x, position.y);
    else
      dom.window.scrollTo(
          {'behavior': 'smooth', 'left': position.x, 'top': position.y});
  }

  /// Scrolls to the top.
  void scrollToTop({bool smoothScroll = true}) =>
      scrollToPosition(const Point(0, 0), smoothScroll: smoothScroll);
}
